==> haskell-glob-0.10.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-glob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Glob
version: 0.10.0
id: Glob-0.10.0-5vHjWmXDjLwL6j2hIM1EYR
key: Glob-0.10.0-5vHjWmXDjLwL6j2hIM1EYR
license: BSD-3-Clause
maintainer: Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author: Matti Niemenmaa
stability: provisional
homepage: http://iki.fi/matti.niemenmaa/glob/
synopsis: Globbing library
description:
    A library for globbing: matching patterns against file paths.
category: System
abi: 9f72e3c9a1aa79ee075f8bb55320ad26
exposed: True
exposed-modules:
    System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules: System.FilePath.Glob.Base
                System.FilePath.Glob.Directory System.FilePath.Glob.Match
                System.FilePath.Glob.Simplify System.FilePath.Glob.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/Glob-0.10.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/Glob-0.10.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/Glob-0.10.0
hs-libraries: HSGlob-0.10.0-5vHjWmXDjLwL6j2hIM1EYR
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0
    dlist-0.8.0.6-CQRMCGRgL5B3ZxhntX4iOr filepath-1.4.2.1
    transformers-0.5.6.2
    transformers-compat-0.6.4-3mIoeQKAFq789cuQC8bUpt
haddock-interfaces: /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html: /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-glob-0.10.0-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-glob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Glob
version: 0.10.0
id: Glob-0.10.0-8UrBvVAvjYDGw5zthBcmiA
key: Glob-0.10.0-8UrBvVAvjYDGw5zthBcmiA
license: BSD-3-Clause
maintainer: Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author: Matti Niemenmaa
stability: provisional
homepage: http://iki.fi/matti.niemenmaa/glob/
synopsis: Globbing library
description:
    A library for globbing: matching patterns against file paths.
category: System
abi: df6507a7b5ec0c7fe8e8f6fcb7743737
exposed: True
exposed-modules:
    System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules: System.FilePath.Glob.Base
                System.FilePath.Glob.Directory System.FilePath.Glob.Match
                System.FilePath.Glob.Simplify System.FilePath.Glob.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/Glob-0.10.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/Glob-0.10.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/Glob-0.10.0
hs-libraries: HSGlob-0.10.0-8UrBvVAvjYDGw5zthBcmiA
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0
    dlist-0.8.0.6-CQRMCGRgL5B3ZxhntX4iOr filepath-1.4.2.1
    transformers-0.5.6.2
    transformers-compat-0.6.4-3mIoeQKAFq789cuQC8bUpt
haddock-interfaces: /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html: /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
